@@ -3,11 +3,12 @@ package Config::Simple::Conf;
 # Licensed under the terms of perl itself.
 
 use strict;
-# Version number - cvs automagically updated.
-our $VERSION = $1 if('$Revision: 1.9 $' =~ /: ([\d\.]+)/);
+
+our $VERSION = "2.001";
+
 
 # Revision - cvs automagically updated
-our $REVISION = '$Id: Conf.pm,v 1.9 2016/05/24 05:45:50 cfaber Exp $';
+our $REVISION = '$Id: Conf.pm,v 1.12 2016/05/25 16:06:20 cfaber Exp $';
 
 # Ruckus Global Version Number
 
@@ -252,11 +253,14 @@ sub _fileargs {
 			# Skip blank lines and comments
 			next if(!$_ || /^#/);
 
-			# We use argv for our arguments string and thus a section named argv is disallowed.
+			# We use argv for our arguments string, and global for our global arguments,  and thus a sections named argv or global are disallowed.
 			if($hd eq 'argv'){
-				&_die("ERROR: section name [argv] is invalid and disallowed: $tfn\:$line" . ($fn ? ' included from: ' . join('-> ', @{$fn}) : undef));
+				&_die("ERROR: section name [argv] is invalid and disallowed: $tfn\:$line" . ($fn ? ' included from: ' . join(' -> ', @{$fn}) : undef));
+			} elsif($hd eq 'global'){
+				&_die("ERROR: section name [global] is invalid and disallowed: $tfn\:$line" . ($fn ? ' included from: ' . join(' -> ', @{$fn}) : undef));
 			}
 
+
 			my ($k, $v) = split(/=/, $_, 2);
 
 			$k =~ s/^\s+//g;
@@ -264,6 +268,8 @@ sub _fileargs {
 			$v =~ s/^\s+//g;
 			$v =~ s/\s+$//g;
 
+			$k = lc $k;
+
 			if($k eq 'die'){
 				&_die("ERROR: $tfn died on line $line: $v in section [$hd] in $tfn" . ($fn ? ' included from: ' . join('-> ', @{$fn}) : undef));
 			} elsif(!$k){
